from setuptools import setup, find_packages

setup(
    name='sgc.py',
    version="0.0.2",
    author='Mochagod123',
    url="https://github.com/mochagod123/sgc.py",
    license='GPL 3.0 license',
    classifiers=[
        "Development Status :: 1 - Planning"
    ],
    packages=find_packages()
)